@@ -29,7 +29,9 @@
 import account
 import project
 import invoice
-import transfer
+import account_bank_statement
+import account_move_line
+import account_analytic_line
 import wizard
 import report
 
