@@ -59,7 +59,7 @@ class account_payment_term(osv.osv):
 			if line.value=='fixed':
 				amt = round(line.value_amount, 2)
 			elif line.value=='procent':
-				amt = round(amount * line.value_amount, 2)
+				amt = round(value * line.value_amount, 2)
 			elif line.value=='balance':
 				amt = round(amount, 2)
 			if amt:
@@ -126,7 +126,10 @@ class account_account(osv.osv):
 	_name = "account.account"
 	_description = "Account"
 
-	def search(self, cr, uid, args, offset=0, limit=None, order=None, context={}):
+	def search(self, cr, uid, args, offset=0, limit=None, order=None,
+			context=None, count=False):
+		if context is None:
+			context = {}
 		pos = 0
 		while pos<len(args):
 			if args[pos][0]=='journal_id':
@@ -142,15 +145,22 @@ class account_account(osv.osv):
 				ids1 += map(lambda x: x.id, jour.account_control_ids)
 				args[pos] = ('id','in',ids1)
 			pos+=1
-		return super(account_account,self).search(cr, uid, args, offset, limit, order, context=context)
+		return super(account_account,self).search(cr, uid, args, offset, limit,
+				order, context=context, count=count)
 
 	def _credit(self, cr, uid, ids, field_name, arg, context={}):
-		if not 'fiscalyear' in context:
-			context['fiscalyear'] = self.pool.get('account.fiscalyear').find(cr, uid,
-					exception=False)
 		acc_set = ",".join(map(str, ids))
 		query = self.pool.get('account.move.line')._query_get(cr, uid, context=context)
-		cr.execute(("SELECT a.id, COALESCE(SUM(l.credit*a.sign),0) FROM account_account a LEFT JOIN account_move_line l ON (a.id=l.account_id) WHERE a.type!='view' AND a.id IN (%s) AND "+query+" GROUP BY a.id") % (acc_set, ))
+		cr.execute(("SELECT a.id, " \
+					"SUM(COALESCE(l.credit * a.sign, 0)) " \
+				"FROM account_account a " \
+					"LEFT JOIN account_move_line l " \
+					"ON (a.id = l.account_id) " \
+				"WHERE a.type != 'view' " \
+					"AND a.id IN (%s) " \
+					"AND " + query + " " \
+					"AND a.active " \
+				"GROUP BY a.id") % (acc_set, ))
 		res2 = cr.fetchall()
 		res = {}
 		for id in ids:
@@ -160,13 +170,18 @@ class account_account(osv.osv):
 		return res
 
 	def _debit(self, cr, uid, ids, field_name, arg, context={}):
-		if not 'fiscalyear' in context:
-			context['fiscalyear'] = self.pool.get('account.fiscalyear').find(cr, uid,
-					exception=False)
-
 		acc_set = ",".join(map(str, ids))
 		query = self.pool.get('account.move.line')._query_get(cr, uid, context=context)
-		cr.execute(("SELECT a.id, COALESCE(SUM(l.debit*a.sign),0) FROM account_account a LEFT JOIN account_move_line l ON (a.id=l.account_id) WHERE a.type!='view' AND a.id IN (%s) and "+query+" GROUP BY a.id") % (acc_set, ))
+		cr.execute(("SELECT a.id, " \
+					"SUM(COALESCE(l.debit * a.sign, 0)) " \
+				"FROM account_account a " \
+					"LEFT JOIN account_move_line l " \
+					"ON (a.id = l.account_id) " \
+				"WHERE a.type != 'view' " \
+					"AND a.id IN (%s) " \
+					"AND " + query + " " \
+					"AND a.active " \
+				"GROUP BY a.id") % (acc_set, ))
 		res2 = cr.fetchall()
 		res = {}
 		for id in ids:
@@ -176,21 +191,27 @@ class account_account(osv.osv):
 		return res
 
 	def _balance(self, cr, uid, ids, field_name, arg, context={}):
-		if not 'fiscalyear' in context:
-			context['fiscalyear'] = self.pool.get('account.fiscalyear').find(cr, uid,
-					exception=False)
-		if not context['fiscalyear']:
-			return dict(map(lambda x: (x, 0.0), ids))
-
 		ids2 = self.search(cr, uid, [('parent_id', 'child_of', ids)])
 		ids2 = {}.fromkeys(ids + ids2).keys()
 		acc_set = ",".join(map(str, ids2))
-		query = self.pool.get('account.move.line')._query_get(cr, uid, context=context)
-		cr.execute(("SELECT a.id, SUM(COALESCE(l.debit,0)-COALESCE(l.credit,0)) FROM account_account a LEFT JOIN account_move_line l ON (a.id=l.account_id) WHERE a.id IN (%s) and "+query+" GROUP BY a.id") % (acc_set, ))
+		query = self.pool.get('account.move.line')._query_get(cr, uid,
+				context=context)
+		cr.execute(("SELECT a.id, " \
+					"SUM((COALESCE(l.debit, 0) - COALESCE(l.credit, 0))) " \
+				"FROM account_account a " \
+					"LEFT JOIN account_move_line l " \
+					"ON (a.id=l.account_id) " \
+				"WHERE a.type != 'view' " \
+					"AND a.id IN (%s) " \
+					"AND " + query + " " \
+					"AND a.active " \
+				"GROUP BY a.id") % (acc_set, ))
 		res = {}
 		for account_id, sum in cr.fetchall():
 			res[account_id] = round(sum,2)
-		cr.execute("SELECT a.id, a.company_id FROM account_account a where id in (%s)" % acc_set)
+		cr.execute("SELECT a.id, a.company_id " \
+				"FROM account_account a " \
+				"WHERE id IN (%s)" % acc_set)
 		resc = dict(cr.fetchall())
 		cr.execute("SELECT id, currency_id FROM res_company")
 		rescur = dict(cr.fetchall())
@@ -203,7 +224,9 @@ class account_account(osv.osv):
 					res.setdefault(id, 0.0)
 					if resc[idx]<>resc[id] and resc[idx] and resc[id]:
 						from_currency_id = rescur[resc[idx]]
-						res[id] += self.pool.get('res.currency').compute(cr, uid, from_currency_id, to_currency_id, res.get(idx, 0.0), context=context)
+						res[id] += self.pool.get('res.currency').compute(cr,
+								uid, from_currency_id, to_currency_id,
+								res.get(idx, 0.0), context=context)
 					else:
 						res[id] += res.get(idx, 0.0)
 		for id in ids:
@@ -230,8 +253,8 @@ class account_account(osv.osv):
 		'reconcile': fields.boolean('Reconcile', help="Check this account if the user can make a reconciliation of the entries in this account."),
 		'shortcut': fields.char('Shortcut', size=12),
 		'close_method': fields.selection([('none','None'), ('balance','Balance'), ('detail','Detail'),('unreconciled','Unreconciled')], 'Deferral Method', required=True, help="Tell Tiny ERP how to process the entries of this account when you close a fiscal year. None removes all entries to start with an empty account for the new fiscal year. Balance creates only one entry to keep the balance for the new fiscal year. Detail keeps the detail of all entries of the preceeding years. Unreconciled keeps the detail of unreconciled entries only."),
-		'tax_ids': fields.many2many('account.tax', 'account_account_tax_default_rel', 'account_id','tax_id', 'Default Taxes'),
-
+		'tax_ids': fields.many2many('account.tax', 'account_account_tax_default_rel',
+			'account_id','tax_id', 'Default Taxes'),
 		'note': fields.text('Note'),
 		'company_currency_id': fields.function(_get_company_currency, method=True, type='many2one', relation='res.currency', string='Company Currency'),
 		'company_id': fields.many2one('res.company', 'Company', required=True),
@@ -501,6 +524,7 @@ account_period()
 class account_journal_period(osv.osv):
 	_name = "account.journal.period"
 	_description = "Journal - Period"
+
 	def _icon_get(self, cr, uid, ids, field_name, arg=None, context={}):
 		result = {}.fromkeys(ids, 'STOCK_NEW')
 		for r in self.read(cr, uid, ids, ['state']):
@@ -510,14 +534,16 @@ class account_journal_period(osv.osv):
 				'done': 'STOCK_DIALOG_AUTHENTICATION',
 			}.get(r['state'], 'STOCK_NEW')
 		return result
+
 	_columns = {
 		'name': fields.char('Journal-Period Name', size=64, required=True),
 		'journal_id': fields.many2one('account.journal', 'Journal', required=True, ondelete="cascade"),
 		'period_id': fields.many2one('account.period', 'Period', required=True, ondelete="cascade"),
-		'icon': fields.function(_icon_get, method=True, string='Icon'),
+		'icon': fields.function(_icon_get, method=True, string='Icon', type='string'),
 		'active': fields.boolean('Active', required=True),
 		'state': fields.selection([('draft','Draft'), ('printed','Printed'), ('done','Done')], 'State', required=True, readonly=True)
 	}
+
 	def _check(self, cr, uid, ids, context={}):
 		for obj in self.browse(cr, uid, ids, context):
 			cr.execute('select * from account_move_line where journal_id=%d and period_id=%d limit 1', (obj.journal_id.id, obj.period_id.id))
@@ -539,6 +565,7 @@ class account_journal_period(osv.osv):
 		'active': lambda *a: True,
 	}
 	_order = "period_id"
+
 account_journal_period()
 
 #----------------------------------------------------------
@@ -566,15 +593,16 @@ class account_move(osv.osv):
 		'state': lambda *a: 'draft',
 		'period_id': _get_period,
 	}
-	def button_validate(self, cr, uid, ids, context={}):
+	def post(self, cr, uid, ids, context=None):
 		if self.validate(cr, uid, ids, context) and len(ids):
 			cr.execute('update account_move set state=%s where id in ('+','.join(map(str,ids))+')', ('posted',))
 		else:
-			cr.execute('update account_move set state=%s where id in ('+','.join(map(str,ids))+')', ('draft',))
-			cr.commit()
 			raise osv.except_osv('Integrity Error !', 'You can not validate a non balanced entry !')
 		return True
 
+	def button_validate(self, cursor, user, ids, context=None):
+		return self.post(cursor, user, ids, context=context)
+
 	def button_cancel(self, cr, uid, ids, context={}):
 		for line in self.browse(cr, uid, ids, context):
 			if not line.journal_id.update_posted:
@@ -631,7 +659,9 @@ class account_move(osv.osv):
 		toremove = []
 		for move in self.browse(cr, uid, ids, context):
 			if move['state'] <> 'draft':
-				raise osv.except_osv('Error', 'You must first cancel the invoice movement: %s !' % move['name'])
+				raise osv.except_osv('UserError',
+						'You can not delete posted movement: "%s"!' % \
+								move['name'])
 			line_ids = map(lambda x: x.id, move.line_id)
 			context['journal_id'] = move.journal_id.id
 			context['period_id'] = move.period_id.id
@@ -725,33 +755,51 @@ class account_move(osv.osv):
 				todo = []
 				account = {}
 				account2 = {}
-				field_base = ''
 				if journal.type not in ('purchase','sale'):
 					continue
-				if journal.type=='purchase':
-					field_base='ref_'
 
 				for line in move.line_id:
+					if move.journal_id.type == 'sale':
+						if line.debit:
+							field_base = 'ref_'
+							key = 'account_paid_id'
+						else:
+							field_base = ''
+							key = 'account_collected_id'
+					else:
+						if line.debit:
+							field_base = ''
+							key = 'account_collected_id'
+						else:
+							field_base = 'ref_'
+							key = 'account_paid_id'
 					if line.account_id.tax_ids:
 						code = amount = False
 						for tax in line.account_id.tax_ids:
 							if tax.tax_code_id:
-								acc = (line.debit >0) and tax.account_paid_id.id or tax.account_collected_id.id
-								account[acc] = (getattr(tax,field_base+'tax_code_id').id, getattr(tax,field_base+'tax_sign'))
-								account2[(acc,getattr(tax,field_base+'tax_code_id').id)] = (getattr(tax,field_base+'tax_code_id').id, getattr(tax,field_base+'tax_sign'))
-								code = getattr(tax,field_base+'base_code_id').id
-								amount = getattr(tax, field_base+'base_sign') * (line.debit + line.credit)
+								acc = getattr(tax, key).id
+								account[acc] = (getattr(tax,
+									field_base + 'tax_code_id').id,
+									getattr(tax, field_base + 'tax_sign'))
+								account2[(acc,getattr(tax,
+									field_base + 'tax_code_id').id)] = (getattr(tax,
+										field_base + 'tax_code_id').id,
+										getattr(tax, field_base + 'tax_sign'))
+								code = getattr(tax, field_base + 'base_code_id').id
+								amount = getattr(tax, field_base+'base_sign') * \
+										(line.debit + line.credit)
 								break
-						if code and not (line.tax_code_id or line.tax_amount): 
-							self.pool.get('account.move.line').write(cr, uid, [line.id], {
+						if code and not (line.tax_code_id or line.tax_amount):
+							self.pool.get('account.move.line').write(cr, uid,
+									[line.id], {
 								'tax_code_id': code,
 								'tax_amount': amount
-							}, context, check=False)
+							}, context=context, check=False)
 					else:
 						todo.append(line)
 				for line in todo:
 					code = amount = 0
-					key = (line.account_id.id,line.tax_code_id.id)
+					key = (line.account_id.id, line.tax_code_id.id)
 					if key in account2:
 						code = account2[key][0]
 						amount = account2[key][1] * (line.debit + line.credit)
@@ -990,11 +1038,42 @@ class account_tax(osv.osv):
 		cur_price_unit=price_unit
 		for tax in taxes:
 			# we compute the amount for the current tax object and append it to the result
+
 			if tax.type=='percent':
 				amount = cur_price_unit * tax.amount
-				res.append({'id':tax.id, 'name':tax.name, 'amount':amount, 'account_collected_id':tax.account_collected_id.id, 'account_paid_id':tax.account_paid_id.id, 'base_code_id': tax.base_code_id.id, 'ref_base_code_id': tax.ref_base_code_id.id, 'sequence': tax.sequence, 'base_sign': tax.base_sign, 'tax_sign': tax.tax_sign, 'ref_base_sign': tax.ref_base_sign, 'ref_tax_sign': tax.ref_tax_sign, 'price_unit': cur_price_unit, 'tax_code_id': tax.tax_code_id.id, 'ref_tax_code_id': tax.ref_tax_code_id.id,})
+				res.append({'id':tax.id,
+							'name':tax.name,
+							'amount':amount,
+							'account_collected_id':tax.account_collected_id.id,
+							'account_paid_id':tax.account_paid_id.id,
+							'base_code_id': tax.base_code_id.id,
+							'ref_base_code_id': tax.ref_base_code_id.id,
+							'sequence': tax.sequence,
+							'base_sign': tax.base_sign,
+							'tax_sign': tax.tax_sign,
+							'ref_base_sign': tax.ref_base_sign,
+							'ref_tax_sign': tax.ref_tax_sign,
+							'price_unit': cur_price_unit,
+							'tax_code_id': tax.tax_code_id.id,
+							'ref_tax_code_id': tax.ref_tax_code_id.id,
+							})
+
 			elif tax.type=='fixed':
-				res.append({'id':tax.id, 'name':tax.name, 'amount':tax.amount, 'account_collected_id':tax.account_collected_id.id, 'account_paid_id':tax.account_paid_id.id, 'base_code_id': tax.base_code_id.id, 'ref_base_code_id': tax.ref_base_code_id.id, 'sequence': tax.sequence, 'base_sign': tax.base_sign, 'tax_sign': tax.tax_sign, 'ref_base_sign': tax.ref_base_sign, 'ref_tax_sign': tax.ref_tax_sign, 'price_unit': 1, 'tax_code_id': tax.tax_code_id.id, 'ref_tax_code_id': tax.ref_tax_code_id.id,})
+				res.append({'id':tax.id,
+							'name':tax.name,
+							'amount':tax.amount,
+							'account_collected_id':tax.account_collected_id.id,
+							'account_paid_id':tax.account_paid_id.id,
+							'base_code_id': tax.base_code_id.id,
+							'ref_base_code_id': tax.ref_base_code_id.id,
+							'sequence': tax.sequence,
+							'base_sign': tax.base_sign,
+							'tax_sign': tax.tax_sign,
+							'ref_base_sign': tax.ref_base_sign,
+							'ref_tax_sign': tax.ref_tax_sign,
+							'price_unit': 1,
+							'tax_code_id': tax.tax_code_id.id,
+							'ref_tax_code_id': tax.ref_tax_code_id.id,})
 			elif tax.type=='code':
 				address = address_id and self.pool.get('res.partner.address').browse(cr, uid, address_id) or None
 				localdict = {'price_unit':cur_price_unit, 'address':address, 'product':product, 'partner':partner}
@@ -1051,11 +1130,42 @@ class account_tax(osv.osv):
 		cur_price_unit=price_unit
 		for tax in taxes:
 			# we compute the amount for the current tax object and append it to the result
+
 			if tax.type=='percent':
 				amount = cur_price_unit - (cur_price_unit / (1 + tax.amount))
-				res.append({'id':tax.id, 'name':tax.name, 'amount':amount, 'account_collected_id':tax.account_collected_id.id, 'account_paid_id':tax.account_paid_id.id, 'base_code_id': tax.base_code_id.id, 'ref_base_code_id': tax.ref_base_code_id.id, 'sequence': tax.sequence, 'base_sign': tax.base_sign, 'tax_sign': tax.tax_sign, 'ref_base_sign': tax.ref_base_sign, 'ref_tax_sign': tax.ref_tax_sign, 'price_unit': cur_price_unit - amount, 'tax_code_id': tax.tax_code_id.id, 'ref_tax_code_id': tax.ref_tax_code_id.id,})
+				res.append({'id':tax.id,
+							'name':tax.name,
+							'amount':amount,
+							'account_collected_id':tax.account_collected_id.id,
+							'account_paid_id':tax.account_paid_id.id,
+							'base_code_id': tax.base_code_id.id,
+							'ref_base_code_id': tax.ref_base_code_id.id,
+							'sequence': tax.sequence,
+							'base_sign': tax.base_sign,
+							'tax_sign': tax.tax_sign,
+							'ref_base_sign': tax.ref_base_sign,
+							'ref_tax_sign': tax.ref_tax_sign,
+							'price_unit': cur_price_unit - amount,
+							'tax_code_id': tax.tax_code_id.id,
+							'ref_tax_code_id': tax.ref_tax_code_id.id,})
+
 			elif tax.type=='fixed':
-				res.append({'id':tax.id, 'name':tax.name, 'amount':tax.amount, 'account_collected_id':tax.account_collected_id.id, 'account_paid_id':tax.account_paid_id.id, 'base_code_id': tax.base_code_id.id, 'ref_base_code_id': tax.ref_base_code_id.id, 'sequence': tax.sequence, 'base_sign': tax.base_sign, 'tax_sign': tax.tax_sign, 'ref_base_sign': tax.ref_base_sign, 'ref_tax_sign': tax.ref_tax_sign, 'price_unit': 1, 'tax_code_id': tax.tax_code_id.id, 'ref_tax_code_id': tax.ref_tax_code_id.id,})
+				res.append({'id':tax.id,
+							'name':tax.name,
+							'amount':tax.amount,
+							'account_collected_id':tax.account_collected_id.id,
+							'account_paid_id':tax.account_paid_id.id,
+							'base_code_id': tax.base_code_id.id,
+							'ref_base_code_id': tax.ref_base_code_id.id,
+							'sequence': tax.sequence,
+							'base_sign': tax.base_sign,
+							'tax_sign': tax.tax_sign,
+							'ref_base_sign': tax.ref_base_sign,
+							'ref_tax_sign': tax.ref_tax_sign,
+							'price_unit': 1,
+							'tax_code_id': tax.tax_code_id.id,
+							'ref_tax_code_id': tax.ref_tax_code_id.id,})
+
 			elif tax.type=='code':
 				address = address_id and self.pool.get('res.partner.address').browse(cr, uid, address_id) or None
 				localdict = {'price_unit':cur_price_unit, 'address':address, 'product':product, 'partner':partner}
@@ -1078,6 +1188,7 @@ class account_tax(osv.osv):
 					'tax_code_id': tax.tax_code_id.id,
 					'ref_tax_code_id': tax.ref_tax_code_id.id,
 				})
+
 			amount2 = res[-1]['amount']
 			if len(tax.child_ids):
 				if tax.child_depend:
@@ -1086,7 +1197,7 @@ class account_tax(osv.osv):
 				else:
 					amount = amount2
 			for t in tax.child_ids:
-				parent_tax = self._unit_compute_inv(cr, uid, [t], amount, address_id)
+				parent_tax = self._unit_compute_inv(cr, uid, [t], amount, address_id, product, partner)
 				res.extend(parent_tax)
 			if tax.include_base_amount:
 				cur_price_unit-=amount
