@@ -38,13 +38,20 @@ class account_move_line(osv.osv):
 	_description = "Entry lines"
 
 	def _query_get(self, cr, uid, obj='l', context={}):
-		if not 'fiscalyear' in context:
-			context['fiscalyear'] = self.pool.get('account.fiscalyear').find(cr, uid, exception=False)
+		fiscalyear_obj = self.pool.get('account.fiscalyear')
+		if not context.get('fiscalyear', False):
+			fiscalyear_ids = fiscalyear_obj.search(cr, uid, [('state', '=', 'draft')])
+			if fiscalyear_ids:
+				fiscalyear_clause = ','.join([str(x) for x in fiscalyear_ids])
+			else:
+				fiscalyear_clause = 'NULL'
+		else:
+			fiscalyear_clause = '%s' % context['fiscalyear']
 		if context.get('periods', False):
 			ids = ','.join([str(x) for x in context['periods']])
-			return obj+".active AND "+obj+".state<>'draft' AND "+obj+".period_id in (SELECT id from account_period WHERE fiscalyear_id=%d AND id in (%s))" % (context['fiscalyear'], ids)
+			return obj+".active AND "+obj+".state<>'draft' AND "+obj+".period_id in (SELECT id from account_period WHERE fiscalyear_id in (%s) AND id in (%s))" % (fiscalyear_clause, ids)
 		else:
-			return obj+".active AND "+obj+".state<>'draft' AND "+obj+".period_id in (SELECT id from account_period WHERE fiscalyear_id=%d)" % (context['fiscalyear'],)
+			return obj+".active AND "+obj+".state<>'draft' AND "+obj+".period_id in (SELECT id from account_period WHERE fiscalyear_id in (%s))" % (fiscalyear_clause,)
 
 	def default_get(self, cr, uid, fields, context={}):
 		data = self._default_get(cr, uid, fields, context)
@@ -70,7 +77,8 @@ class account_move_line(osv.osv):
 						account_move_line \
 					where \
 						journal_id=%d and period_id=%d and create_uid=%d and state=%s \
-					order by id desc limit 1', (context['journal_id'], context['period_id'], uid, 'draft'))
+					order by id desc limit 1',
+					(context['journal_id'], context['period_id'], uid, 'draft'))
 				res = cr.fetchone()
 				move_id = (res and res[0]) or False
 				if not move_id:
@@ -82,10 +90,15 @@ class account_move_line(osv.osv):
 					from \
 						account_move_line \
 					where \
-						journal_id=%d and period_id=%d and create_uid=%d order by id desc', (context['journal_id'], context['period_id'], uid))
+						journal_id=%d and period_id=%d and create_uid=%d \
+					order by id desc',
+					(context['journal_id'], context['period_id'], uid))
 				res = cr.fetchone()
 				data['date'] = res and res[0] or time.strftime('%Y-%m-%d')
 
+		if not move_id:
+			return data
+
 		total = 0
 		ref_id = False
 		taxes = {}
@@ -95,9 +108,22 @@ class account_move_line(osv.osv):
 			ref_id = ref_id or l.ref
 			total += (l.debit - l.credit)
 			for tax in l.account_id.tax_ids:
-				acc = (l.debit >0) and tax.account_paid_id.id or tax.account_collected_id.id
-				taxes.setdefault((acc,tax.tax_code_id.id), False)
-			taxes[(l.account_id.id,l.tax_code_id.id)] = True
+				if move.journal_id.type == 'sale':
+					if l.debit:
+						code = tax.ref_tax_code_id.id
+						acc = tax.account_paid_id.id
+					else:
+						code = tax.tax_code_id.id
+						acc = tax.account_collected_id.id
+				else:
+					if l.debit:
+						code = tax.tax_code_id.id
+						acc = tax.account_collected_id.id
+					else:
+						code = tax.ref_tax_code_id.id
+						acc = tax.account_paid_id.id
+				taxes.setdefault((acc, code), False)
+			taxes[(l.account_id.id, l.tax_code_id.id)] = True
 			if 'name' in fields:
 				data.setdefault('name', l.name)
 
@@ -107,20 +133,35 @@ class account_move_line(osv.osv):
 			data['partner_id'] = partner_id
 
 		if move.journal_id.type in ('purchase', 'sale'):
-			field_base=''
-			if move.journal_id.type=='purchase':
-				field_base='ref_'
 			for t in taxes:
 				if not taxes[t] and t[0]:
-					s=0
+					s = 0
+					tax_amount = 0
 					for l in move.line_id:
-						key = (l.debit and 'account_paid_id') or 'account_collected_id'
-						for tax in self.pool.get('account.tax').compute(cr, uid, l.account_id.tax_ids, l.debit or l.credit, 1, False):
-							if (tax[key] == t[0]) and (tax[field_base+'tax_code_id']==t[1]):
+						if move.journal_id.type == 'sale':
+							if l.debit:
+								field_base = 'ref_'
+								key = 'account_paid_id'
+							else:
+								field_base = ''
+								key = 'account_collected_id'
+						else:
+							if l.debit:
+								field_base = ''
+								key = 'account_collected_id'
+							else:
+								field_base = 'ref_'
+								key = 'account_paid_id'
+						for tax in self.pool.get('account.tax').compute(cr, uid,
+								l.account_id.tax_ids, l.debit or l.credit, 1, False):
+							if (tax[key] == t[0]) \
+									and (tax[field_base + 'tax_code_id'] == t[1]):
 								if l.debit:
 									s += tax['amount']
 								else:
 									s -= tax['amount']
+								tax_amount += tax['amount'] * \
+										tax[field_base + 'tax_sign']
 					if ('debit' in fields) or ('credit' in fields):
 						data['debit'] = s>0  and s or 0.0
 						data['credit'] = s<0  and -s or 0.0
@@ -129,6 +170,8 @@ class account_move_line(osv.osv):
 						data['tax_code_id'] = t[1]
 					if 'account_id' in fields:
 						data['account_id'] = t[0]
+					if 'tax_amount' in fields:
+						data['tax_amount'] = tax_amount
 					#
 					# Compute line for tax T
 					#
@@ -141,7 +184,7 @@ class account_move_line(osv.osv):
 			data['credit'] = total>0 and total
 			data['debit'] = total<0 and -total
 		if 'account_id' in fields:
-			if total>=0:
+			if total >= 0:
 				data['account_id'] = move.journal_id.default_credit_account_id.id or False
 			else:
 				data['account_id'] = move.journal_id.default_debit_account_id.id or False
