@@ -68,7 +68,7 @@ class account_invoice(osv.osv):
 			return res[0]
 		else:
 			return False
-	
+
 	def _get_currency(self, cr, uid, context):
 		user = pooler.get_pool(cr.dbname).get('res.users').browse(cr, uid, [uid])[0]
 		if user.company_id:
@@ -136,7 +136,7 @@ class account_invoice(osv.osv):
 
 		'period_id': fields.many2one('account.period', 'Force Period', help="Keep empty to use the period of the validation date."),
 
-		'account_id': fields.many2one('account.account', 'Dest Account', required=True, readonly=True, states={'draft':[('readonly',False)]}),
+		'account_id': fields.many2one('account.account', 'Account', required=True, readonly=True, states={'draft':[('readonly',False)]}),
 		'invoice_line': fields.one2many('account.invoice.line', 'invoice_id', 'Invoice Lines', readonly=True, states={'draft':[('readonly',False)]}),
 		'tax_line': fields.one2many('account.invoice.tax', 'invoice_id', 'Tax Lines', readonly=True, states={'draft':[('readonly',False)]}),
 
@@ -177,15 +177,15 @@ class account_invoice(osv.osv):
 #		res = self.pool.get('res.partner').address_get(cr, uid, [part], ['invoice'])
 #		return [{}]
 
-	def onchange_partner_id(self, cr, uid, ids, type, partner_id):
+	def onchange_partner_id(self, cr, uid, ids, type, partner_id, date_invoice=False, payment_term=False):
 		invoice_addr_id = False
 		contact_addr_id = False
-		payment_term = False
+		partner_payment_term = False
 		acc_id = False
-		
+
 		opt = [('uid', str(uid))]
 		if partner_id:
-			
+
 			opt.insert(0, ('id', partner_id))
 			res = self.pool.get('res.partner').address_get(cr, uid, [partner_id], ['contact', 'invoice'])
 			contact_addr_id = res['contact']
@@ -196,22 +196,27 @@ class account_invoice(osv.osv):
 			else:
 				acc_id = p.property_account_payable.id
 
-			payment_term = p.property_payment_term and p.property_payment_term.id or False
+			partner_payment_term = p.property_payment_term and p.property_payment_term.id or False
 
 		result = {'value': {
 			'address_contact_id': contact_addr_id,
 			'address_invoice_id': invoice_addr_id,
 			'account_id': acc_id,
-			'payment_term':payment_term}
+			'payment_term': partner_payment_term}
 		}
 
-		if partner_id and p.property_payment_term.id:
-			result['value']['payment_term'] = p.property_payment_term.id
+		if payment_term != partner_payment_term:
+			if partner_payment_term:
+				to_update = self.onchange_payment_term_date_invoice(
+					cr,uid,ids,partner_payment_term,date_invoice)
+				result['value'].update(to_update['value'])
+			else:
+				result['value']['date_due'] = False
 		return result
 
 	def onchange_currency_id(self, cr, uid, ids, curr_id):
 		return {}
-	
+
 	def onchange_payment_term_date_invoice(self, cr, uid, ids, payment_term_id, date_invoice):
 		if not payment_term_id:
 			return {}
@@ -219,7 +224,7 @@ class account_invoice(osv.osv):
 		pt_obj= self.pool.get('account.payment.term')
 
 		if not date_invoice :
-			date_invoice= time.strftime('%Y-%m-%d')
+			date_invoice = self._defaults["date_invoice"](cr,uid,{})
 
 		pterm_list= pt_obj.compute(cr, uid, payment_term_id, value=1, date_ref=date_invoice)
 
@@ -356,7 +361,6 @@ class account_invoice(osv.osv):
 			if inv.move_id:
 				continue
 			if inv.type in ('in_invoice', 'in_refund') and abs(inv.check_total - inv.amount_total) >= (inv.currency_id.rounding/2.0):
-				print inv.check_total,  inv.amount_total
 				raise osv.except_osv('Bad total !', 'Please verify the price of the invoice !\nThe real total does not match the computed total.')
 			company_currency = inv.company_id.currency_id.id
 			# create the analytical lines
@@ -378,7 +382,7 @@ class account_invoice(osv.osv):
 					tax_key.append(key)
 					if not key in compute_taxes:
 						raise osv.except_osv('Warning !', 'Global taxes defined, but not in invoice lines !')
-					base = cur_obj.compute(cr, uid, inv.currency_id.id, company_currency, compute_taxes[key]['base'], context={'date': inv.date_invoice})
+					base = compute_taxes[key]['base']
 					if abs(base - tax.base) > inv.company_id.currency_id.rounding:
 						raise osv.except_osv('Warning !', 'Tax base different !\nClick on compute to update tax base')
 				for key in compute_taxes:
@@ -421,7 +425,7 @@ class account_invoice(osv.osv):
 			totlines = False
 			if inv.payment_term:
 				totlines = self.pool.get('account.payment.term').compute(cr,
-						uid, inv.payment_term.id, total)
+						uid, inv.payment_term.id, total, inv.date_invoice)
 			if totlines:
 				res_amount_currency = total_currency
 				i = 0
@@ -481,7 +485,7 @@ class account_invoice(osv.osv):
 			move_id = self.pool.get('account.move').create(cr, uid, move)
 			# make the invoice point to that move
 			self.write(cr, uid, [inv.id], {'move_id': move_id})
-			self.pool.get('account.move').write(cr, uid, [move_id], {'state':'posted'})
+			self.pool.get('account.move').post(cr, uid, [move_id])
 		self._log_event(cr, uid, ids)
 		return True
 
@@ -490,7 +494,7 @@ class account_invoice(osv.osv):
 			'date':date,
 			'date_maturity': x.get('date_maturity', False),
 			'partner_id':part,
-			'name':x['name'],
+			'name':x['name'][:64],
 			'debit':x['price']>0 and x['price'],
 			'credit':x['price']<0 and -x['price'],
 			'account_id':x['account_id'],
@@ -503,17 +507,27 @@ class account_invoice(osv.osv):
 		}
 
 	def action_number(self, cr, uid, ids, *args):
-		cr.execute('SELECT id, type, number, move_id, reference FROM account_invoice WHERE id IN ('+','.join(map(str,ids))+')')
+		cr.execute('SELECT id, type, number, move_id, reference ' \
+				'FROM account_invoice ' \
+				'WHERE id IN ('+','.join(map(str,ids))+')')
 		for (id, invtype, number, move_id, reference) in cr.fetchall():
 			if not number:
-				number = self.pool.get('ir.sequence').get(cr, uid, 'account.invoice.'+invtype)
+				number = self.pool.get('ir.sequence').get(cr, uid,
+						'account.invoice.' + invtype)
 				if type in ('in_invoice', 'in_refund'):
 					ref = reference
 				else:
 					ref = self._convert_ref(cr, uid, number)
-				cr.execute('UPDATE account_invoice SET number=%s WHERE id=%d', (number, id))
-				cr.execute('UPDATE account_move_line SET ref=%s WHERE move_id=%d and ref is null', (ref, move_id))
-				cr.execute('UPDATE account_analytic_line SET ref=%s FROM account_move_line WHERE account_move_line.move_id=%d AND account_analytic_line.move_id=account_move_line.id', (ref, move_id))
+				cr.execute('UPDATE account_invoice SET number=%s ' \
+						'WHERE id=%d', (number, id))
+				cr.execute('UPDATE account_move_line SET ref=%s ' \
+						'WHERE move_id=%d AND (ref is null OR ref = \'\')',
+						(ref, move_id))
+				cr.execute('UPDATE account_analytic_line SET ref=%s ' \
+						'FROM account_move_line ' \
+						'WHERE account_move_line.move_id = %d ' \
+							'AND account_analytic_line.move_id = account_move_line.id',
+							(ref, move_id))
 		return True
 
 	def action_cancel(self, cr, uid, ids, *args):
@@ -523,7 +537,7 @@ class account_invoice(osv.osv):
 			if i['move_id']:
 				account_move_obj.button_cancel(cr, uid, [i['move_id'][0]])
 				# delete the move this invoice was pointing to
-				# Note that the corresponding move_lines and move_reconciles 
+				# Note that the corresponding move_lines and move_reconciles
 				# will be automatically deleted too
 				account_move_obj.unlink(cr, uid, [i['move_id'][0]])
 		self.write(cr, uid, ids, {'state':'cancel', 'move_id':False})
@@ -600,27 +614,27 @@ class account_invoice(osv.osv):
 		return map(lambda x: (0,0,x), lines)
 
 	def refund(self, cr, uid, ids):
-		invoices = self.read(cr, uid, ids, ['name', 'type', 'number', 'reference', 'comment', 'date_due', 'partner_id', 'address_contact_id', 'address_invoice_id', 'partner_contact', 'partner_insite', 'partner_ref', 'payment_term', 'account_id', 'currency_id', 'invoice_line', 'tax_line'])
+		invoices = self.read(cr, uid, ids, ['name', 'type', 'number', 'reference', 'comment', 'date_due', 'partner_id', 'address_contact_id', 'address_invoice_id', 'partner_contact', 'partner_insite', 'partner_ref', 'payment_term', 'account_id', 'currency_id', 'invoice_line', 'tax_line', 'journal_id'])
 
 		new_ids = []
 		for invoice in invoices:
 			del invoice['id']
-			
+
 			type_dict = {
 				'out_invoice': 'out_refund', # Customer Invoice
 				'in_invoice': 'in_refund',   # Supplier Invoice
 				'out_refund': 'out_invoice', # Customer Refund
 				'in_refund': 'in_invoice',   # Supplier Refund
 			}
-			
-				
+
+
 			invoice_lines = self.pool.get('account.invoice.line').read(cr, uid, invoice['invoice_line'])
 			invoice_lines = self._refund_cleanup_lines(invoice_lines)
-			
+
 			tax_lines = self.pool.get('account.invoice.tax').read(cr, uid, invoice['tax_line'])
 			tax_lines = filter(lambda l: l['manual'], tax_lines)
 			tax_lines = self._refund_cleanup_lines(tax_lines)
-			
+
 			invoice.update({
 				'type': type_dict[invoice['type']],
 				'date_invoice': time.strftime('%Y-%m-%d'),
@@ -629,10 +643,10 @@ class account_invoice(osv.osv):
 				'invoice_line': invoice_lines,
 				'tax_line': tax_lines
 			})
-		
+
 			# take the id part of the tuple returned for many2one fields
-			for field in ('address_contact_id', 'address_invoice_id', 'partner_id', 
-					'account_id', 'currency_id', 'payment_term'):
+			for field in ('address_contact_id', 'address_invoice_id', 'partner_id',
+					'account_id', 'currency_id', 'payment_term', 'journal_id'):
 				invoice[field] = invoice[field] and invoice[field][0]
 
 			# create the new invoice
@@ -670,7 +684,7 @@ class account_invoice(osv.osv):
 		lines = [(0, 0, l1), (0, 0, l2)]
 		move = {'name': name, 'line_id': lines, 'journal_id': pay_journal_id, 'period_id': period_id}
 		move_id = self.pool.get('account.move').create(cr, uid, move)
-		
+
 		line_ids = []
 		line = self.pool.get('account.move.line')
 		cr.execute('select id from account_move_line where move_id in ('+str(move_id)+','+str(invoice.move_id.id)+')')
@@ -713,7 +727,7 @@ class account_invoice_line(osv.osv):
 		'invoice_id': fields.many2one('account.invoice', 'Invoice Ref', ondelete='cascade', select=True),
 		'uos_id': fields.many2one('product.uom', 'Unit', ondelete='set null'),
 		'product_id': fields.many2one('product.product', 'Product', ondelete='set null'),
-		'account_id': fields.many2one('account.account', 'Source Account', required=True, domain=[('type','<>','view'), ('type', '<>', 'closed')]),
+		'account_id': fields.many2one('account.account', 'Account', required=True, domain=[('type','<>','view'), ('type', '<>', 'closed')]),
 		'price_unit': fields.float('Unit Price', required=True, digits=(16, int(config['price_accuracy']))),
 		'price_subtotal': fields.function(_amount_line, method=True, string='Subtotal'),
 		'quantity': fields.float('Quantity', required=True),
@@ -800,23 +814,44 @@ class account_invoice_line(osv.osv):
 		cur_obj = self.pool.get('res.currency')
 		ait_obj = self.pool.get('account.invoice.tax')
 		inv = self.pool.get('account.invoice').browse(cr, uid, invoice_id)
+		company_currency = inv.company_id.currency_id.id
 		cur = inv.currency_id
 
 		for line in inv.invoice_line:
-			res.append( self.move_line_get_item(cr, uid, line, context))
-			for tax in tax_obj.compute(cr, uid, line.invoice_line_tax_id, (line.price_unit *(1.0-(line['discount'] or 0.0)/100.0)), line.quantity, inv.address_invoice_id.id, line.product_id, inv.partner_id):
+			res.append(self.move_line_get_item(cr, uid, line, context))
+			tax_code_found= False
+			for tax in tax_obj.compute(cr, uid, line.invoice_line_tax_id,
+					(line.price_unit * (1.0 - (line['discount'] or 0.0) / 100.0)),
+					line.quantity, inv.address_invoice_id.id, line.product_id,
+					inv.partner_id):
+
 				if inv.type in ('out_invoice', 'in_invoice'):
-					res[-1]['tax_code_id'] = tax['base_code_id']
-					res[-1]['tax_amount'] = tax['price_unit'] * line['quantity'] * tax['base_sign']
+					tax_code_id = tax['base_code_id']
+					tax_amount = tax['price_unit'] * \
+							line['quantity'] * tax['base_sign']
 				else:
-					res[-1]['tax_code_id'] = tax['ref_base_code_id']
-					res[-1]['tax_amount'] = tax['price_unit'] * line['quantity'] * tax['ref_base_sign']
+					tax_code_id = tax['ref_base_code_id']
+					tax_amount = tax['price_unit'] * \
+							line['quantity'] * tax['ref_base_sign']
+
+				if tax_code_found:
+					if not tax_code_id:
+						continue
+					res.append(self.move_line_get_item(cr, uid, line, context))
+					res[-1]['price'] = 0.0
+					res[-1]['account_analytic_id'] = False
+				elif not tax_code_id:
+					continue
+				tax_code_found = True
+
+				res[-1]['tax_code_id'] = tax_code_id
+				res[-1]['tax_amount'] = cur_obj.compute(cr, uid, inv.currency_id.id, company_currency, tax_amount, context={'date': inv.date_invoice})
 		return res
 
 	def move_line_get_item(self, cr, uid, line, context={}):
 		return {
 				'type':'src',
-				'name':line.name,
+				'name': line.name[:64],
 				'price_unit':line.price_unit,
 				'quantity':line.quantity,
 				'price':line.price_subtotal,
@@ -827,7 +862,7 @@ class account_invoice_line(osv.osv):
 			}
 	#
 	# Set the tax field according to the account and the partner
-	# 
+	#
 	def onchange_account_id(self, cr, uid, ids, partner_id,account_id):
 		if not (partner_id and account_id):
 			return {}
@@ -876,6 +911,7 @@ class account_invoice_tax(osv.osv):
 		cur_obj = self.pool.get('res.currency')
 		inv = self.pool.get('account.invoice').browse(cr, uid, invoice_id)
 		cur = inv.currency_id
+		company_currency = inv.company_id.currency_id.id
 
 		for line in inv.invoice_line:
 			for tax in tax_obj.compute(cr, uid, line.invoice_line_tax_id, (line.price_unit* (1-(line.discount or 0.0)/100.0)), line.quantity, inv.address_invoice_id.id, line.product_id, inv.partner_id):
@@ -890,14 +926,14 @@ class account_invoice_tax(osv.osv):
 				if inv.type in ('out_invoice','in_invoice'):
 					val['base_code_id'] = tax['base_code_id']
 					val['tax_code_id'] = tax['tax_code_id']
-					val['base_amount'] = val['base'] * tax['base_sign']
-					val['tax_amount'] = val['amount'] * tax['tax_sign']
+					val['base_amount'] = cur_obj.compute(cr, uid, inv.currency_id.id, company_currency, val['base'] * tax['base_sign'], context={'date': inv.date_invoice})
+					val['tax_amount'] = cur_obj.compute(cr, uid, inv.currency_id.id, company_currency, val['amount'] * tax['tax_sign'], context={'date': inv.date_invoice})
 					val['account_id'] = tax['account_collected_id'] or line.account_id.id
 				else:
 					val['base_code_id'] = tax['ref_base_code_id']
 					val['tax_code_id'] = tax['ref_tax_code_id']
-					val['base_amount'] = val['base'] * tax['ref_base_sign']
-					val['tax_amount'] = val['amount'] * tax['ref_tax_sign']
+					val['base_amount'] = cur_obj.compute(cr, uid, inv.currency_id.id, company_currency, val['base'] * tax['ref_base_sign'], context={'date': inv.date_invoice})
+					val['tax_amount'] = cur_obj.compute(cr, uid, inv.currency_id.id, company_currency, val['amount'] * tax['ref_tax_sign'], context={'date': inv.date_invoice})
 					val['account_id'] = tax['account_paid_id'] or line.account_id.id
 
 				key = (val['tax_code_id'], val['base_code_id'], val['account_id'])
@@ -915,6 +951,10 @@ class account_invoice_tax(osv.osv):
 		res = []
 		cr.execute('SELECT * FROM account_invoice_tax WHERE invoice_id=%d', (invoice_id,))
 		for t in cr.dictfetchall():
+			if not t['amount'] \
+					and not t['tax_code_id'] \
+					and not t['tax_amount']:
+				continue
 			res.append({
 				'type':'tax',
 				'name':t['name'],
@@ -927,4 +967,3 @@ class account_invoice_tax(osv.osv):
 			})
 		return res
 account_invoice_tax()
-
