@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id$
+# $Id: rappel.py 7974 2007-11-27 16:45:31Z ced $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -56,7 +56,7 @@ class report_rappel(report_sxw.rml_parse):
 				[('partner_id', '=', partner.id),
 					('account_id.type', 'in', ['receivable', 'payable']),
 					('state', '<>', 'draft'), ('reconcile_id', '=', False)])
-		movelines = moveline_obj.read(self.cr, self.uid, movelines)
+		movelines = moveline_obj.browse(self.cr, self.uid, movelines)
 		return movelines
 
 report_sxw.report_sxw('report.account.rappel', 'res.partner',
