@@ -64,20 +64,15 @@ class ir_sequence(osv.osv):
 		return (s or '') % {'year':time.strftime('%Y'), 'month': time.strftime('%m'), 'day':time.strftime('%d')}
 
 	def get_id(self, cr, uid, sequence_id, test='id=%d'):
-		try:
-			cr.execute('lock table ir_sequence')
-			cr.execute('select id,number_next,number_increment,prefix,suffix,padding from ir_sequence where '+test+' and active=True', (sequence_id,))
-			res = cr.dictfetchone()
-			if res:
-				cr.execute('update ir_sequence set number_next=number_next+number_increment where id=%d and active=True', (res['id'],))
-				if res['number_next']:
-					return self._process(res['prefix']) + '%%0%sd' % res['padding'] % res['number_next'] + self._process(res['suffix'])
-				else:
-					return self._process(res['prefix']) + self._process(res['suffix'])
-			cr.commit()
-		except:
-			cr.rollback()
-			return False
+		cr.execute('lock table ir_sequence')
+		cr.execute('select id,number_next,number_increment,prefix,suffix,padding from ir_sequence where '+test+' and active=True', (sequence_id,))
+		res = cr.dictfetchone()
+		if res:
+			cr.execute('update ir_sequence set number_next=number_next+number_increment where id=%d and active=True', (res['id'],))
+			if res['number_next']:
+				return self._process(res['prefix']) + '%%0%sd' % res['padding'] % res['number_next'] + self._process(res['suffix'])
+			else:
+				return self._process(res['prefix']) + self._process(res['suffix'])
 		return False
 
 	def get(self, cr, uid, code):
