@@ -31,24 +31,61 @@ import pickle
 
 class ir_values(osv.osv):
 	_name = 'ir.values'
+
+	def _value_unpickle(self, cursor, user, ids, name, arg, context=None):
+		res = {}
+		for report in self.browse(cursor, user, ids, context=context):
+			value = report[name[:-9]]
+			if not report.object and value:
+				try:
+					value = str(pickle.loads(value))
+				except:
+					pass
+			res[report.id] = value
+		return res
+
+	def _value_pickle(self, cursor, user, id, name, value, arg, context=None):
+		if context is None:
+			context = {}
+		ctx = context.copy()
+		if 'read_delta' in ctx:
+			del ctx['read_delta']
+		if not self.browse(cursor, user, id, context=context).object:
+			value = pickle.dumps(eval(value))
+		self.write(cursor, user, id, {name[:-9]: value}, context=ctx)
+
 	_columns = {
 		'name': fields.char('Name', size=128),
-		'model': fields.char('Name', size=128),
+		'model': fields.char('Model', size=128),
 		'value': fields.text('Value'),
+		'value_unpickle': fields.function(_value_unpickle, fnct_inv=_value_pickle,
+			method=True, type='text', string='Value'),
 		'object': fields.boolean('Is Object'),
-		'key': fields.char('Name', size=128),
+		'key': fields.char('Type', size=128),
 		'key2': fields.char('Value', size=256),
 		'meta': fields.text('Meta Datas'),
+		'meta_unpickle': fields.function(_value_unpickle, fnct_inv=_value_pickle,
+			method=True, type='text', string='Meta Datas'),
 		'res_id': fields.integer('Resource ID'),
-		'user_id': fields.many2one('res.users', 'User', ondelete='cascade')
+		'user_id': fields.many2one('res.users', 'User', ondelete='cascade'),
+		'company_id': fields.many2one('res.company', 'Company')
 	}
 	_defaults = {
 		'key': lambda *a: 'action',
 		'key2': lambda *a: 'tree_but_open',
+		'company_id': lambda *a: False
 	}
-	def set(self, cr, uid, key, key2, name, models, value, replace=True, isobject=False, meta=False, preserve_user=False):
+
+	def _auto_init(self, cr):
+		super(ir_values, self)._auto_init(cr)
+		cr.execute('SELECT indexname FROM pg_indexes WHERE indexname = \'ir_values_key_model_key2_index\'')
+		if not cr.fetchone():
+			cr.execute('CREATE INDEX ir_values_key_model_key2_index ON ir_values (key, model, key2)')
+			cr.commit()
+
+	def set(self, cr, uid, key, key2, name, models, value, replace=True, isobject=False, meta=False, preserve_user=False, company=False):
 		if type(value)==type(u''):
-			value  = value.encode('utf8')
+			value = value.encode('utf8')
 		if not isobject:
 			value = pickle.dumps(value)
 		if meta:
@@ -60,7 +97,24 @@ class ir_values(osv.osv):
 			else:
 				res_id=False
 			if replace:
-				ids = self.search(cr, uid, [('key','=',key),('key2','=',key2),('name','=',name),('model','=',model),('res_id','=',res_id), ('user_id','=',preserve_user and uid)])
+				if key in ('meta', 'default'):
+					ids = self.search(cr, uid, [
+						('key', '=', key),
+						('key2', '=', key2),
+						('name', '=', name),
+						('model', '=', model),
+						('res_id', '=', res_id),
+						('user_id', '=', preserve_user and uid)
+						])
+				else:
+					ids = self.search(cr, uid, [
+						('key', '=', key),
+						('key2', '=', key2),
+						('value', '=', value),
+						('model', '=', model),
+						('res_id', '=', res_id),
+						('user_id', '=', preserve_user and uid)
+						])
 				self.unlink(cr, uid, ids)
 			vals = {
 				'name': name,
@@ -72,6 +126,9 @@ class ir_values(osv.osv):
 				'meta': meta,
 				'user_id': preserve_user and uid,
 			}
+			if company:
+				cid = self.pool.get('res.users').browse(cr, uid, uid, context={}).company_id.id
+				vals['company_id']=cid
 			if res_id:
 				vals['res_id']= res_id
 			ids_res.append(self.create(cr, uid, vals))
@@ -86,7 +143,7 @@ class ir_values(osv.osv):
 				res_id=False
 			
 			where1 = ['key=%s','model=%s']
-			where2 = [key,m]
+			where2 = [key,str(m)]
 			where_opt = []
 			if key2:
 				where1.append('key2=%s')
@@ -102,22 +159,27 @@ class ir_values(osv.osv):
 					where1.append('res_id=%d' % (res_id,))
 				else:
 					where1.append('(res_id is NULL)')
-			else:
-				if res_id:
-					if (models[-1][0]==m):
-						where1.append('(res_id=%d or (res_id is null))' % (res_id,))
-						where_opt.append('res_id=%d' % (res_id,))
-					else:
-						where1.append('res_id=%d' % (res_id,))
+			elif res_id:
+				if (models[-1][0]==m):
+					where1.append('(res_id=%d or (res_id is null))' % (res_id,))
+					where_opt.append('res_id=%d' % (res_id,))
+				else:
+					where1.append('res_id=%d' % (res_id,))
 
 #			if not without_user:
 			where_opt.append('user_id=%d' % (uid,))
 
+
 			result = []
 			ok = True
-			while ok and len(result)==0:
-				cr.execute('select id from ir_values where '+' and '.join(where1+where_opt), where2)
-				result = [x[0] for x in cr.fetchall()]
+			while ok:
+				if not where_opt:
+					cr.execute('select id from ir_values where ' +\
+							' and '.join(where1)+' and user_id is null', where2)
+				else:
+					cr.execute('select id from ir_values where ' +\
+							' and '.join(where1+where_opt), where2)
+				result.extend([x[0] for x in cr.fetchall()])
 				if len(where_opt):
 					where_opt.pop()
 				else:
@@ -128,24 +190,44 @@ class ir_values(osv.osv):
 
 		if not result:
 			return []
-		cr.execute('select id,name,value,object,meta from ir_values where id in ('+','.join(map(str,result))+')')
+		cid = self.pool.get('res.users').browse(cr, uid, uid, context={}).company_id.id
+		cr.execute('select id,name,value,object,meta, key ' \
+				'from ir_values ' \
+				'where id in ('+','.join(map(str,result))+') ' \
+					'and (company_id is null or company_id = %d) '\
+				'ORDER BY user_id', (cid,))
 		result = cr.fetchall()
 
-		def _result_get(x):
+		def _result_get(x, keys):
+			if x[1] in keys:
+				return False
+			keys.append(x[1])
 			if x[3]:
 				model,id = x[2].split(',')
-				datas = self.pool.get(model).read(cr, uid, [int(id)], False, context)
+				try:
+					id = int(id)
+				except:
+					return False
+				datas = self.pool.get(model).read(cr, uid, [id], False, context)
 				if not len(datas):
 					#ir_del(cr, uid, x[0])
 					return False
-				datas = datas[0]
+				def clean(x):
+					for key in ('report_sxw_content', 'report_rml_content',
+							'report_sxw', 'report_rml', 'report_sxw_content_data',
+							'report_rml_content_data'):
+						if key in x:
+							del x[key]
+					return x
+				datas = clean(datas[0])
 			else:
 				datas = pickle.loads(x[2])
 			if meta:
 				meta2 = pickle.loads(x[4])
 				return (x[0],x[1],datas,meta2)
 			return (x[0],x[1],datas)
-		res = filter(bool, map(lambda x: _result_get(x), list(result)))
+		keys = []
+		res = filter(bool, map(lambda x: _result_get(x, keys), list(result)))
 		return res
 ir_values()
 
