@@ -34,7 +34,7 @@ import os
 
 view_form_profit = """<?xml version="1.0"?>
 <form string="Setup">
-	<image name="gtk-info"/>
+	<image name="gtk-dialog-info"/>
 	<group>
 		<separator string="Select a profile" colspan="2"/>
 		<newline/>
@@ -48,23 +48,25 @@ view_form_profit = """<?xml version="1.0"?>
 
 view_form_charts = """<?xml version="1.0"?>
 <form string="Setup">
-	<image name="gtk-info" size="64" colspan="2"/>
+	<image name="gtk-dialog-info" colspan="2"/>
 	<group>
 		<separator string="Select a chart of accounts" colspan="2"/>
 		<newline/>
 		<field name="charts" align="0.0"/>
 		<newline/>
+		<label string="There is many other charts on http://www.tinyerp.com/" colspan="2" align="0.0"/>
+		<newline/>
 		<label string="(If you don't select a chart of accounts, you'll need to set up one manually)." colspan="2" align="0.0"/>
 	</group>
 </form>"""
 
 view_form_company = """<?xml version="1.0"?>
 <form string="Setup">
-	<image name="gtk-info" size="64" colspan="2"/>
+	<image name="gtk-dialog-info" colspan="2"/>
 	<group>
 		<separator string="Define main company" colspan="4"/>
 		<newline/>
-		<field name="name" align="0.0" colspan="3" required="True"/>
+		<field name="name" align="0.0" colspan="4" required="True"/>
 		<newline/>
 		<field name="street" align="0.0"/>
 		<field name="street2" align="0.0"/>
@@ -74,17 +76,18 @@ view_form_company = """<?xml version="1.0"?>
 		<field name="state_id" align="0.0"/>
 		<field name="email" align="0.0"/>
 		<field name="phone" align="0.0"/>
+		<field name="currency" align="0.0"/>
 		<separator string="Report header" colspan="4"/>
 		<newline/>
-		<field name="rml_header1" align="0.0" colspan="3"/>
-		<field name="rml_footer1" align="0.0" colspan="3"/>
-		<field name="rml_footer2" align="0.0" colspan="3"/>
+		<field name="rml_header1" align="0.0" colspan="4"/>
+		<field name="rml_footer1" align="0.0" colspan="4"/>
+		<field name="rml_footer2" align="0.0" colspan="4"/>
 	</group>
 </form>"""
 
 view_form_update = """<?xml version="1.0"?>
 <form string="Setup">
-	<image name="gtk-info" size="64" colspan="2"/>
+	<image name="gtk-dialog-info" colspan="2"/>
 	<group>
 		<separator string="Summary" colspan="2"/>
 		<newline/>
@@ -99,7 +102,7 @@ view_form_update = """<?xml version="1.0"?>
 
 view_form_finish = """<?xml version="1.0"?>
 <form string="Setup">
-	<image name="gtk-info" size="64" colspan="2"/>
+	<image name="gtk-dialog-info" colspan="2"/>
 	<group colspan="2" col="4">
 		<separator colspan="4" string="Installation done"/>
 		<label align="0.0" colspan="4" string="Your new database is now fully installed."/>
@@ -131,6 +134,7 @@ class wizard_base_setup(wizard.interface):
 			return {}
 		company=company_obj.browse(cr, uid, ids)[0]
 		self.fields['name']['default']=company.name
+		self.fields['currency']['default']=company.currency_id.id
 		return {}
 		#self.fields['rml_header1']['default']=company.rml_header1
 		#self.fields['rml_footer1']['default']=company.rml_footer1
@@ -188,6 +192,7 @@ class wizard_base_setup(wizard.interface):
 				'rml_header1': form['rml_header1'],
 				'rml_footer1': form['rml_footer1'],
 				'rml_footer2': form['rml_footer2'],
+				'currency_id': form['currency'],
 			})
 		partner_obj.write(cr, uid, [company.partner_id.id], {
 				'name': form['name'],
@@ -200,7 +205,7 @@ class wizard_base_setup(wizard.interface):
 					'city': form['city'],
 					'email': form['email'],
 					'phone': form['phone'],
-					'country_id': form['country_id']
+					'country_id': form['country_id'],
 				}
 		if form['state_id'] > 0:
 			values['state_id']=form['state_id']
@@ -218,27 +223,36 @@ class wizard_base_setup(wizard.interface):
 		lang_ids=lang_obj.search(cr, uid, [])
 		langs=lang_obj.browse(cr, uid, lang_ids)
 		for lang in langs:
-			if lang.code and lang.code != 'en_EN':
+			if lang.code and lang.code != 'en_US':
 				filename=os.path.join(tools.config["root_path"], "i18n", lang.code + ".csv")
 				tools.trans_load(cr.dbname, filename, lang.code)
 		return {}
+
 	def _menu(self, cr, uid, data, context):
 		users_obj=pooler.get_pool(cr.dbname).get('res.users')
-		actions_obj=pooler.get_pool(cr.dbname).get('ir.actions.act_window')
-		
-		ids=actions_obj.search(cr, uid, [('name', '=', 'Menu')])
-		menu=actions_obj.browse(cr, uid, ids)[0]
+		action_obj=pooler.get_pool(cr.dbname).get('ir.actions.act_window')
+
+		ids=action_obj.search(cr, uid, [('name', '=', 'Menu')])
+		menu=action_obj.browse(cr, uid, ids)[0]
 
 		ids=users_obj.search(cr, uid, [('action_id', '=', 'Setup')])
 		users_obj.write(cr, uid, ids, {'action_id': menu.id})
+		ids=users_obj.search(cr, uid, [('menu_id', '=', 'Setup')])
+		users_obj.write(cr, uid, ids, {'menu_id': menu.id})
+
 		return {
-			'name': 'Menu',
-			'type':'ir.actions.act_window',
-			'res_model':'ir.ui.menu',
-			'view_type':'tree',
-			'domain': "[('parent_id','=',False)]",
-			'view_id': (menu.view_id.id, menu.view_id.name),
+			'name': menu.name,
+			'type': menu.type,
+			'view_id': (menu.view_id and\
+					(menu.view_id.id, menu.view_id.name)) or False,
+			'domain': menu.domain,
+			'res_model': menu.res_model,
+			'src_model': menu.src_model,
+			'view_type': menu.view_type,
+			'view_mode': menu.view_mode,
+			'views': menu.views,
 		}
+
 	def _next(self, cr, uid, data, context):
 		if not data['form']['profile'] or data['form']['profile'] <= 0:
 			return 'company'
@@ -278,7 +292,7 @@ class wizard_base_setup(wizard.interface):
 			'size': 128,
 		},
 		'zip':{
-			'string': 'Zip',
+			'string': 'Zip code',
 			'type': 'char',
 			'size': 24,
 		},
@@ -307,6 +321,12 @@ class wizard_base_setup(wizard.interface):
 			'type': 'char',
 			'size': 64,
 		},
+		'currency': {
+			'string': 'Currency',
+			'type': 'many2one',
+			'relation': 'res.currency',
+			'required': True,
+		},
 		'rml_header1':{
 			'string': 'Report Header',
 			'type': 'char',
@@ -325,36 +345,60 @@ class wizard_base_setup(wizard.interface):
 	}
 	states={
 		'init':{
-			'actions':[_get_company],
-			'result':{'type':'form', 'arch':view_form_profit, 'fields':fields, 'state':[('menu', 'Cancel', 'gtk-cancel'), ('next', 'Next', 'gtk-go-forward')]}
+			'actions': [_get_company],
+			'result': {'type': 'form', 'arch': view_form_profit, 'fields': fields,
+				'state': [
+					('menu', 'Cancel', 'gtk-cancel'),
+					('next', 'Next', 'gtk-go-forward', True)
+				]
+			}
 		},
 		'next': {
-			'actions':[],
-			'result':{'type':'choice', 'next_state': _next}
+			'actions': [],
+			'result': {'type': 'choice', 'next_state': _next}
 		},
 		'charts':{
-			'actions':[],
-			'result':{'type':'form', 'arch':view_form_charts, 'fields':fields, 'state':[('init', 'Previous', 'gtk-go-back'), ('company', 'Next', 'gtk-go-forward')]}
+			'actions': [],
+			'result': {'type': 'form', 'arch': view_form_charts, 'fields': fields,
+				'state':[
+					('init', 'Previous', 'gtk-go-back'),
+					('company', 'Next', 'gtk-go-forward', True)
+				]
+			}
 		},
 		'company':{
-			'actions':[],
-			'result':{'type':'form', 'arch':view_form_company, 'fields':fields, 'state':[('previous', 'Previous', 'gtk-go-back'), ('update', 'Next', 'gtk-go-forward')]}
+			'actions': [],
+			'result': {'type': 'form', 'arch': view_form_company, 'fields': fields,
+				'state': [
+					('previous', 'Previous', 'gtk-go-back'),
+					('update', 'Next', 'gtk-go-forward', True)
+				]
+			}
 		},
 		'previous':{
-			'actions':[],
-			'result':{'type':'choice', 'next_state': _previous}
+			'actions': [],
+			'result': {'type': 'choice', 'next_state': _previous}
 		},
 		'update':{
-			'actions':[],
-			'result':{'type':'form', 'arch':view_form_update, 'fields':fields, 'state':[('company', 'Previous', 'gtk-go-back'), ('finish', 'Install', 'gtk-ok')]}
+			'actions': [],
+			'result': {'type': 'form', 'arch': view_form_update, 'fields': fields,
+				'state': [
+					('company', 'Previous', 'gtk-go-back'),
+					('finish', 'Install', 'gtk-ok', True)
+				]
+			}
 		},
 		'finish':{
-			'actions':[_update],
-			'result':{'type':'form', 'arch':view_form_finish, 'fields':{}, 'state':[('menu', 'Ok', 'gtk-ok')]}
+			'actions': [_update],
+			'result': {'type': 'form', 'arch': view_form_finish, 'fields': {},
+				'state': [
+					('menu', 'Ok', 'gtk-ok', True)
+				]
+			}
 		},
 		'menu': {
-			'actions':[],
-			'result':{'type':'action', 'action':_menu, 'state':'end'}
-		}
+			'actions': [],
+			'result': {'type': 'action', 'action': _menu, 'state': 'end'}
+		},
 	}
 wizard_base_setup('base_setup.base_setup')
