@@ -286,6 +286,10 @@ class crm_case(osv.osv):
 		'date_action_last': fields.datetime('Last Action', readonly=1),
 		'date_action_next': fields.datetime('Next Action', readonly=1),
 	}
+	def copy(self, cr, uid, id, default=None, context={}):
+		if not default: default = {}
+		default.update( {'state':'draft', 'id':False, 'history_line':[],'log_ids':[]})
+		return super(crm_case, self).copy(cr, uid, id, default, context)
 	_defaults = {
 		'active': lambda *a: 1,
 		'user_id': lambda s,cr,uid,c={}: uid,
@@ -427,8 +431,11 @@ class crm_case(osv.osv):
 			return False
 		for case in cases:
 			if case.partner_id:
+				name = 'Case ' + keyword + ': ' + case.name
+				if len(name) > 64:
+					name = name[:61] + '...'
 				self.pool.get('res.partner.event').create(cr, uid, {
-					'name':'Case '+keyword+': '+case.name,
+					'name': name,
 					'som':(case.som or False) and case.som.id,
 					'description':case.description,
 					'partner_id':case.partner_id.id,
