@@ -168,7 +168,7 @@ class sale_order(osv.osv):
 		'incoterm': fields.selection(_incoterm_get, 'Incoterm',size=3),
 		'picking_policy': fields.selection([('direct','Direct Delivery'),('one','All at once')], 'Packing Policy', required=True ),
 		'order_policy': fields.selection([
-			('prepaid','Invoice before delivery'),
+			('prepaid','Payment before delivery'),
 			('manual','Shipping & Manual Invoice'),
 			('postpaid','Automatic Invoice after delivery'),
 			('picking','Invoice from the packings'),
@@ -261,7 +261,7 @@ class sale_order(osv.osv):
 					inv_line_id = self.pool.get('account.invoice.line').copy(cr, uid, preline.id, {'invoice_id':False, 'price_unit':-preline.price_unit})
 					lines.append(inv_line_id)
 		inv = {
-			'name': order.name,
+			'name': order.client_order_ref or order.name,
 			'origin': order.name,
 			'type': 'out_invoice',
 			'reference': "P%dSO%d"%(order.partner_id.id,order.id),
@@ -442,7 +442,7 @@ class sale_order(osv.osv):
 						})
 
 					move_id = self.pool.get('stock.move').create(cr, uid, {
-						'name':line.name,
+						'name': line.name[:64],
 						'picking_id': picking_id,
 						'product_id': line.product_id.id,
 						'date_planned': date_planned,
@@ -607,7 +607,7 @@ class sale_order_line(osv.osv):
 		'th_weight' : fields.float('Weight'),
 		'state': fields.selection([('draft','Draft'),('confirmed','Confirmed'),('done','Done'),('cancel','Canceled')], 'State', required=True, readonly=True),
 	}
-	_order = 'sequence'
+	_order = 'sequence, id'
 	_defaults = {
 		'discount': lambda *a: 0.0,
 		'delay': lambda *a: 0.0,
@@ -622,9 +622,22 @@ class sale_order_line(osv.osv):
 	def invoice_line_create(self, cr, uid, ids, context={}):
 		def _get_line_qty(line):
 			if (line.order_id.invoice_quantity=='order') or not line.procurement_id:
-				return line.product_uos_qty or line.product_uom_qty
+				if line.product_uos:
+					return line.product_uos_qty or 0.0
+				return line.product_uom_qty
 			else:
-				return self.pool.get('mrp.procurement').quantity_get(cr, uid, line.procurement_id.id, context)
+				return self.pool.get('mrp.procurement').quantity_get(cr, uid,
+						line.procurement_id.id, context)
+
+		def _get_line_uom(line):
+			if (line.order_id.invoice_quantity=='order') or not line.procurement_id:
+				if line.product_uos:
+					return line.product_uos.id
+				return line.product_uom.id
+			else:
+				return self.pool.get('mrp.procurement').uom_get(cr, uid,
+						line.procurement_id.id, context)
+
 		create_ids = []
 		for line in self.browse(cr, uid, ids, context):
 			if not line.invoiced:
@@ -633,14 +646,20 @@ class sale_order_line(osv.osv):
 					if not a:
 						a = line.product_id.categ_id.property_account_income_categ.id
 					if not a:
-						raise osv.except_osv('Error !', 'There is no income account defined for this product: "%s" (id:%d)' % (line.product_id.name, line.product_id.id,))
+						raise osv.except_osv('Error !',
+								'There is no income account defined ' \
+										'for this product: "%s" (id:%d)' % \
+										(line.product_id.name, line.product_id.id,))
 				else:
-					a = self.pool.get('ir.property').get(cr, uid, 'property_account_income_categ', 'product.category', context=context)
+					a = self.pool.get('ir.property').get(cr, uid,
+							'property_account_income_categ', 'product.category',
+							context=context)
 				uosqty = _get_line_qty(line)
-				uos_id = (line.product_uos and line.product_uos.id) or line.product_uom.id
-				pu = line.price_unit
-				if line.product_uos_qty:
-					pu = round(pu * line.product_uom_qty / line.product_uos_qty, int(config['price_accuracy']))
+				uos_id = _get_line_uom(line)
+				pu = 0.0
+				if uosqty:
+					pu = round(line.price_unit * line.product_uom_qty / uosqty,
+							int(config['price_accuracy']))
 				inv_id = self.pool.get('account.invoice.line').create(cr, uid, {
 					'name': line.name,
 					'account_id': a,
@@ -677,7 +696,7 @@ class sale_order_line(osv.osv):
 
 		product = product_obj.browse(cr, uid, product_id)
 		value = {
-			'product_uom' : product.uom_id,
+			'product_uom' : product.uom_id.id,
 		}
 		# FIXME must depend on uos/uom of the product and not only of the coeff.
 		try:
@@ -704,7 +723,7 @@ class sale_order_line(osv.osv):
 
 		if partner_id:
 			lang = partner_obj.browse(cr, uid, partner_id).lang
-		context = {'lang': lang}
+		context = {'lang': lang, 'partner_id': partner_id}
 
 		if not product:
 			return {'value': {'price_unit': 0.0, 'notes':'', 'th_weight' : 0,
@@ -797,4 +816,17 @@ class sale_order_line(osv.osv):
 			result['th_weight'] = result['product_uom_qty'] * product.weight
 		return {'value': result, 'domain': domain}
 
+	def product_uom_change(self, cursor, user, ids, pricelist, product, qty=0,
+			uom=False, qty_uos=0, uos=False, name='', partner_id=False,
+			lang=False, update_tax=True, date_order=False):
+		res = self.product_id_change(cursor, user, ids, pricelist, product,
+				qty=0, uom=uom, qty_uos=qty_uos, uos=uos, name=name,
+				partner_id=partner_id, lang=lang, update_tax=update_tax,
+				date_order=date_order)
+		if 'product_uom' in res['value']:
+			del res['value']['product_uom']
+		if not uom:
+			res['value']['price_unit'] = 0.0
+		return res
+
 sale_order_line()
