@@ -134,7 +134,7 @@ class stock_location(osv.osv):
 						continue
 					product = products_by_id[product_id]
 					result.append({
-						'price': product.list_price,
+						'price': product.standard_price,
 						'name': product.name,
 						'code': product.default_code, # used by lot_overview_all report!
 						'variants': product.variants or '',
@@ -144,15 +144,20 @@ class stock_location(osv.osv):
 		return result
 
 	def _product_get_multi_location(self, cr, uid, ids, product_ids=False, context={}, states=['done'], what=('in', 'out')):
+		product_obj = self.pool.get('product.product')
 		states_str = ','.join(map(lambda s: "'%s'" % s, states))
 		if not product_ids:
-			product_ids = self.pool.get('product.product').search(cr, uid, [])
+			product_ids = product_obj.search(cr, uid, [])
 		res = {}
 		for id in product_ids:
 			res[id] = 0.0
 		if not ids:
 			return res
-			
+
+		product2uom = {}
+		for product in product_obj.browse(cr, uid, product_ids, context=context):
+			product2uom[product.id] = product.uom_id.id
+
 		prod_ids_str = ','.join(map(str, product_ids))
 		location_ids_str = ','.join(map(str, ids))
 		results = []
@@ -184,11 +189,11 @@ class stock_location(osv.osv):
 		uom_obj = self.pool.get('product.uom')
 		for amount, prod_id, prod_uom in results:
 			amount = uom_obj._compute_qty(cr, uid, prod_uom, amount,
-					context.get('uom', False))
+					context.get('uom', False) or product2uom[prod_id])
 			res[prod_id] += amount
 		for amount, prod_id, prod_uom in results2:
 			amount = uom_obj._compute_qty(cr, uid, prod_uom, amount,
-					context.get('uom', False))
+					context.get('uom', False) or product2uom[prod_id])
 			res[prod_id] -= amount
 		return res
 
@@ -464,13 +469,13 @@ class stock_picking(osv.osv):
 	#
 	# TODO: change and create a move if not parents
 	#
-	def action_done(self, cr, uid, ids, *args):
+	def action_done(self, cr, uid, ids, context=None):
 		for pick in self.browse(cr, uid, ids):
 			if pick.move_type=='one' and pick.loc_move_id:
 				if pick.lot_id:
 					id = self.pool.get('stock.move.lot').create(cr, uid, {
-						'name': 'MOVE:'+pick.name,
-						'origin': 'PICK:'+str(pick.id),
+						'name': pick.name,
+						'origin': str(pick.origin or ''),
 						'lot_id': pick.lot_id.id,
 						'loc_dest_id': pick.loc_move_id.id,
 						'address_id': pick.address_id.id
@@ -487,7 +492,8 @@ class stock_picking(osv.osv):
 					todo.append(move.id)
 
 			if len(todo):
-				self.pool.get('stock.move').action_done(cr, uid, todo)
+				self.pool.get('stock.move').action_done(cr, uid, todo,
+						context=context)
 
 				lot_id = self.pool.get('stock.lot').create(cr, uid, {'name':pick.name})
 				self.pool.get('stock.move').write(cr,uid, todo, {'lot_id':lot_id})
@@ -495,8 +501,8 @@ class stock_picking(osv.osv):
 
 				if pick.move_type=='direct' and pick.loc_move_id:
 					id = self.pool.get('stock.move.lot').create(cr, uid, {
-						'name': 'MOVE:'+pick.name,
-						'origin': 'PICK:'+str(pick.id),
+						'name': pick.name or '/',
+						'origin': str(pick.origin or ''),
 						'lot_id': lot_id,
 						'loc_dest_id': pick.loc_move_id.id,
 						'address_id': pick.address_id.id
@@ -863,7 +869,7 @@ class stock_move(osv.osv):
 		self.action_cancel(cr,uid, ids2, context)
 		return True
 
-	def action_done(self, cr, uid, ids, *args):
+	def action_done(self, cr, uid, ids, context=None):
 		for move in self.browse(cr, uid, ids):
 			if move.move_dest_id.id and (move.state != 'done'):
 				mid = move.move_dest_id.id
@@ -961,6 +967,15 @@ class stock_move(osv.osv):
 			wf_service.trg_trigger(uid, 'stock.move', id, cr)
 		return True
 
+
+	def unlink(self, cr, uid, ids, context=None):
+		for move in self.browse(cr, uid, ids, context=context):
+			if move.state != 'draft':
+				raise osv.except_osv('UserError',
+						'You can only delete draft moves.')
+		return super(stock_move, self).unlink(
+			cr, uid, ids, context=context)
+
 stock_move()
 
 class stock_inventory(osv.osv):
@@ -981,7 +996,7 @@ class stock_inventory(osv.osv):
 	#
 	# Update to support tracking
 	#
-	def action_done(self, cr, uid, ids, *args):
+	def action_done(self, cr, uid, ids, context=None):
 		for inv in self.browse(cr,uid,ids):
 			move_ids = []
 			move_line=[]
@@ -1014,7 +1029,8 @@ class stock_inventory(osv.osv):
 						})
 					move_ids.append(self.pool.get('stock.move').create(cr, uid, value))
 			if len(move_ids):
-				self.pool.get('stock.move').action_done(cr, uid, move_ids)
+				self.pool.get('stock.move').action_done(cr, uid, move_ids,
+						context=context)
 			self.write(cr, uid, [inv.id], {'state':'done', 'date_done': time.strftime('%Y-%m-%d %H:%M:%S'), 'move_ids': [(6,0,move_ids)]})
 		return True
 
