@@ -377,7 +377,7 @@ class orm(object):
 						cr.execute("CREATE INDEX \"%s_%s_index\" ON \"%s\" (\"%s\")" % (f._rel,f._id2,f._rel,f._id2))
 						cr.commit()
 				else:
-					cr.execute("SELECT c.relname,a.attname,a.attlen,a.atttypmod,a.attnotnull,a.atthasdef,t.typname,CASE WHEN a.attlen=-1 THEN a.atttypmod-4 ELSE a.attlen END as size FROM pg_class c,pg_attribute a,pg_type t WHERE c.relname=%s AND a.attname=%s AND c.oid=a.attrelid AND a.atttypid=t.oid", (self._table, k.lower()))
+					cr.execute("SELECT c.relname,a.attname,a.attlen,a.atttypmod,a.attnotnull,a.atthasdef,t.typname,CASE WHEN a.attlen=-1 THEN a.atttypmod-4 ELSE a.attlen END as size FROM pg_class c,pg_attribute a,pg_type t WHERE c.relname=%s AND a.attname=%s AND c.oid=a.attrelid AND a.atttypid=t.oid", (self._table, k))
 					res = cr.dictfetchall() 
 					if not res:
 						if not isinstance(f,fields.function) or f.store:
@@ -464,6 +464,37 @@ class orm(object):
 							if res and not f.select:
 								cr.execute("DROP INDEX \"%s_%s_index\"" % (self._table, k))
 								cr.commit()
+							if isinstance(f, fields.many2one):
+								ref = self.pool.get(f._obj)._table
+								if ref != 'ir_actions':
+									cr.execute('SELECT confdeltype, conname FROM pg_constraint as con, pg_class as cl1, pg_class as cl2, ' \
+												'pg_attribute as att1, pg_attribute as att2 ' \
+											'WHERE con.conrelid = cl1.oid ' \
+												'AND cl1.relname = %s ' \
+												'AND con.confrelid = cl2.oid ' \
+												'AND cl2.relname = %s ' \
+												'AND array_lower(con.conkey, 1) = 1 ' \
+												'AND con.conkey[1] = att1.attnum ' \
+												'AND att1.attrelid = cl1.oid ' \
+												'AND att1.attname = %s ' \
+												'AND array_lower(con.confkey, 1) = 1 ' \
+												'AND con.confkey[1] = att2.attnum ' \
+												'AND att2.attrelid = cl2.oid ' \
+												'AND att2.attname = %s ' \
+												'AND con.contype = \'f\'', (self._table, ref, k, 'id'))
+									res = cr.dictfetchall()
+									if res:
+										confdeltype = {
+											'RESTRICT': 'r',
+											'NO ACTION': 'a',
+											'CASCADE': 'c',
+											'SET NULL': 'n',
+											'SET DEFAULT': 'd',
+										}
+										if res[0]['confdeltype'] != confdeltype.get(f.ondelete.upper(), 'a'):
+											cr.execute('ALTER TABLE "' + self._table + '" DROP CONSTRAINT "' + res[0]['conname'] + '"')
+											cr.execute('ALTER TABLE "' + self._table + '" ADD FOREIGN KEY ("' + k + '") REFERENCES "' + ref + '" ON DELETE ' + f.ondelete)
+											cr.commit()
 					else:
 						print "ERROR"
 		else:
@@ -754,6 +785,7 @@ class orm(object):
 		done = 0
 
 		while len(datas):
+			res = {}
 			try:
 				(res, other, warning, translate, data_id) = \
 						process_liness(self, datas, [], fields_def)
@@ -899,12 +931,13 @@ class orm(object):
 		res = ir_values_obj.get(cr, uid, 'default', False, [self._name])
 		for id, field, field_value in res:
 			if field in fields:
-				if self._columns[field]._type in ('many2one', 'one2one'):
-					obj = self.pool.get(self._columns[field]._obj)
+				fld_def = (field in self._columns) and self._columns[field] or self._inherit_fields[field][2]
+				if fld_def._type in ('many2one', 'one2one'):
+					obj = self.pool.get(fld_def._obj)
 					if not obj.search(cr, uid, [('id', '=', field_value)]):
 						continue
-				if self._columns[field]._type in ('many2many'):
-					obj = self.pool.get(self._columns[field]._obj)
+				if fld_def._type in ('many2many'):
+					obj = self.pool.get(fld_def._obj)
 					field_value2 = []
 					for i in range(len(field_value)):
 						if not obj.search(cr, uid, [('id', '=',
@@ -912,8 +945,8 @@ class orm(object):
 							continue
 						field_value2.append(field_value[i])
 					field_value = field_value2
-				if self._columns[field]._type in ('one2many'):
-					obj = self.pool.get(self._columns[field]._obj)
+				if fld_def._type in ('one2many'):
+					obj = self.pool.get(fld_def._obj)
 					field_value2 = []
 					for i in range(len(field_value)):
 						field_value2.append({})
@@ -1167,8 +1200,9 @@ class orm(object):
 
 	def _update_function_stored(self, cr, user, ids, context=None):
 		if not context:
-			context={}
-		f=filter(lambda a: isinstance(self._columns[a], fields.function) and self._columns[a].store, self._columns)
+			context = {}
+		f = filter(lambda a: isinstance(self._columns[a], fields.function) \
+				and self._columns[a].store, self._columns)
 		if f:
 			result=self.read(cr, user, ids, fields=f, context=context)
 			for res in result:
@@ -1177,10 +1211,14 @@ class orm(object):
 				for field in res:
 					if field not in f:
 						continue
+					value = res[field]
+					if self._columns[field]._type in ('many2one', 'one2one'):
+						value = res[field][0]
 					upd0.append('"'+field+'"='+self._columns[field]._symbol_set[0])
-					upd1.append(self._columns[field]._symbol_set[1](res[field]))
+					upd1.append(self._columns[field]._symbol_set[1](value))
 				upd1.append(res['id'])
-				cr.execute('update "'+self._table+'" set '+string.join(upd0,',')+ ' where id = %d', upd1)
+				cr.execute('update "' + self._table + '" set ' + \
+						string.join(upd0, ',') + ' where id = %d', upd1)
 		return True
 
 	#
@@ -1320,7 +1358,7 @@ class orm(object):
 		elif node.nodeType==node.ELEMENT_NODE and node.localName in ('form','tree'):
 			result = self.view_header_get(cr, user, False, node.localName, context)
 			if result:
-				node.setAttribute('string', result)
+				node.setAttribute('string', result.decode('utf-8'))
 
 		if node.nodeType == node.ELEMENT_NODE:
 			# translate view
@@ -1346,13 +1384,13 @@ class orm(object):
 				for id, fname, gname in res:
 					if oldgroup != gname:
 						child = doc.createElement('separator')
-						child.setAttribute('string', gname)
+						child.setAttribute('string', gname.decode('utf-8'))
 						child.setAttribute('colspan', "4")
 						oldgroup = gname
 						parent.insertBefore(child, node)
 
 					child = doc.createElement('field')
-					child.setAttribute('name', fname)
+					child.setAttribute('name', fname.decode('utf-8'))
 					parent.insertBefore(child, node)
 				parent.removeChild(node)
 
@@ -1749,17 +1787,16 @@ class orm(object):
 
 	def search_count(self, cr, user, args, context=None):
 		if not context:
-			context={}
-		ctx = context.copy()
-		ctx['search_count'] = 1
-		res = self.search(cr, user, args, context=ctx)
+			context = {}
+		res = self.search(cr, user, args, context=context, count=True)
 		if isinstance(res, list):
 			return len(res)
 		return res
 
-	def search(self, cr, user, args, offset=0, limit=None, order=None, context=None):
+	def search(self, cr, user, args, offset=0, limit=None, order=None,
+			context=None, count=False):
 		if not context:
-			context={}
+			context = {}
 		# compute the where, order by, limit and offset clauses
 		(qu1,qu2,tables) = self._where_calc(cr, user, args, context=context)
 
@@ -1779,7 +1816,7 @@ class orm(object):
 			qu1 = qu1 and qu1+' and '+d1 or ' where '+d1
 			qu2 += d2
 
-		if context and context.get('search_count', False):
+		if count:
 			cr.execute('select count(%s.id) from ' % self._table +
 					','.join(tables) +qu1 + limit_str + offset_str, qu2)
 			res = cr.fetchall()
