@@ -183,7 +183,9 @@ class rml_parse(object):
 		except Exception,e:
 			import traceback, sys
 			tb_s = reduce(lambda x, y: x+y, traceback.format_exception(sys.exc_type, sys.exc_value, sys.exc_traceback))
-			netsvc.Logger().notifyChannel('report', netsvc.LOG_ERROR, 'report %s:\n%s\n%s\nexpr: %s' % (self.name, tb_s, str(e), expr))
+			netsvc.Logger().notifyChannel('report', netsvc.LOG_ERROR,
+					'report %s:\n%s\n%s\nexpr: %s' % (self.name, tb_s, str(e),
+						expr.encode('utf-8')))
 			res = ''
 		return res
 
